@@ -14,7 +14,13 @@ from swh.storage import get_storage
 from swh.storage.interface import StorageInterface
 
 LObjectType = Literal[
-    "content", "skipped_content", "directory", "revision", "release", "snapshot"
+    "content",
+    "skipped_content",
+    "directory",
+    "revision",
+    "release",
+    "snapshot",
+    "extid",
 ]
 OBJECT_TYPES: Tuple[LObjectType, ...] = (
     "content",
@@ -23,6 +29,7 @@ OBJECT_TYPES: Tuple[LObjectType, ...] = (
     "revision",
     "release",
     "snapshot",
+    "extid",
 )
 
 DEFAULT_BUFFER_THRESHOLDS: Dict[str, int] = {
@@ -33,6 +40,7 @@ DEFAULT_BUFFER_THRESHOLDS: Dict[str, int] = {
     "revision": 100000,
     "release": 100000,
     "snapshot": 25000,
+    "extid": 10000,
 }
 
 
@@ -86,9 +94,10 @@ class BufferingProxyStorage:
         """Push contents to write to the storage in the buffer.
 
         Following policies apply:
-            - if the buffer's threshold is hit, flush content to the storage.
-            - otherwise, if the total size of buffered contents's threshold is hit,
-            flush content to the storage.
+
+        - if the buffer's threshold is hit, flush content to the storage.
+        - otherwise, if the total size of buffered contents's threshold is hit,
+          flush content to the storage.
 
         """
         stats = self.object_add(
