@@ -13,6 +13,7 @@ from swh.core.db import BaseDb
 from swh.core.db.db_utils import execute_values_generator
 from swh.core.db.db_utils import jsonize as _jsonize
 from swh.core.db.db_utils import stored_procedure
+from swh.model.identifiers import ObjectType
 from swh.model.model import SHA1_SIZE, OriginVisit, OriginVisitStatus
 from swh.storage.interface import ListOrder
 
@@ -28,7 +29,7 @@ class Db(BaseDb):
 
     """
 
-    current_version = 167
+    current_version = 173
 
     def mktemp_dir_entry(self, entry_type, cur=None):
         self._cursor(cur).execute(
@@ -76,6 +77,10 @@ class Db(BaseDb):
     def revision_add_from_temp(self, cur=None):
         pass
 
+    @stored_procedure("swh_extid_add")
+    def extid_add_from_temp(self, cur=None):
+        pass
+
     @stored_procedure("swh_release_add")
     def release_add_from_temp(self, cur=None):
         pass
@@ -234,15 +239,17 @@ class Db(BaseDb):
 
     snapshot_count_cols = ["target_type", "count"]
 
-    def snapshot_count_branches(self, snapshot_id, cur=None):
+    def snapshot_count_branches(
+        self, snapshot_id, branch_name_exclude_prefix=None, cur=None,
+    ):
         cur = self._cursor(cur)
         query = """\
-           SELECT %s FROM swh_snapshot_count_branches(%%s)
+           SELECT %s FROM swh_snapshot_count_branches(%%s, %%s)
         """ % ", ".join(
             self.snapshot_count_cols
         )
 
-        cur.execute(query, (snapshot_id,))
+        cur.execute(query, (snapshot_id, branch_name_exclude_prefix))
 
         yield from cur
 
@@ -254,17 +261,29 @@ class Db(BaseDb):
         branches_from=b"",
         branches_count=None,
         target_types=None,
+        branch_name_include_substring=None,
+        branch_name_exclude_prefix=None,
         cur=None,
     ):
         cur = self._cursor(cur)
         query = """\
-           SELECT %s
-           FROM swh_snapshot_get_by_id(%%s, %%s, %%s, %%s :: snapshot_target[])
+        SELECT %s
+        FROM swh_snapshot_get_by_id(%%s, %%s, %%s, %%s :: snapshot_target[], %%s, %%s)
         """ % ", ".join(
             self.snapshot_get_cols
         )
 
-        cur.execute(query, (snapshot_id, branches_from, branches_count, target_types))
+        cur.execute(
+            query,
+            (
+                snapshot_id,
+                branches_from,
+                branches_count,
+                target_types,
+                branch_name_include_substring,
+                branch_name_exclude_prefix,
+            ),
+        )
 
         yield from cur
 
@@ -812,6 +831,51 @@ class Db(BaseDb):
             ((sortkey, id) for sortkey, id in enumerate(revisions)),
         )
 
+    extid_cols = ["extid", "extid_type", "target", "target_type"]
+
+    def extid_get_from_extid_list(self, extid_type, ids, cur=None):
+        cur = self._cursor(cur)
+        query_keys = ", ".join(
+            self.mangle_query_key(k, "extid") for k in self.extid_cols
+        )
+        sql = """
+            SELECT %s
+            FROM (VALUES %%s) as t(sortkey, extid, extid_type)
+            LEFT JOIN extid USING (extid, extid_type)
+            ORDER BY sortkey
+            """ % (
+            query_keys,
+        )
+
+        yield from execute_values_generator(
+            cur,
+            sql,
+            (((sortkey, extid, extid_type) for sortkey, extid in enumerate(ids))),
+        )
+
+    def extid_get_from_swhid_list(self, target_type, ids, cur=None):
+        cur = self._cursor(cur)
+        target_type = ObjectType(
+            target_type
+        ).name.lower()  # aka "rev" -> "revision", ...
+        query_keys = ", ".join(
+            self.mangle_query_key(k, "extid") for k in self.extid_cols
+        )
+        sql = """
+            SELECT %s
+            FROM (VALUES %%s) as t(sortkey, target, target_type)
+            LEFT JOIN extid USING (target, target_type)
+            ORDER BY sortkey
+            """ % (
+            query_keys,
+        )
+        yield from execute_values_generator(
+            cur,
+            sql,
+            (((sortkey, target, target_type) for sortkey, target in enumerate(ids))),
+            template=b"(%s,%s,%s::object_type)",
+        )
+
     def revision_log(self, root_revisions, limit=None, cur=None):
         cur = self._cursor(cur)
 
@@ -982,6 +1046,7 @@ class Db(BaseDb):
         limit=50,
         regexp=False,
         with_visit=False,
+        visit_types=None,
         cur=None,
     ):
         """
@@ -1014,16 +1079,28 @@ class Db(BaseDb):
             FROM filtered_origins AS o
             """
 
-        if with_visit:
-            query += """
-                   WHERE EXISTS (
-                     SELECT 1
-                     FROM origin_visit ov
-                     INNER JOIN origin_visit_status ovs USING (origin, visit)
-                     INNER JOIN snapshot ON ovs.snapshot=snapshot.id
-                     WHERE ov.origin=o.id
-                     )
-            """
+        if with_visit or visit_types:
+            visit_predicat = (
+                """
+                INNER JOIN origin_visit_status ovs USING (origin, visit)
+                INNER JOIN snapshot ON ovs.snapshot=snapshot.id
+                """
+                if with_visit
+                else ""
+            )
+
+            type_predicat = (
+                f"AND ov.type=any(ARRAY{visit_types})" if visit_types else ""
+            )
+
+            query += f"""
+                WHERE EXISTS (
+                    SELECT 1
+                    FROM origin_visit ov
+                    {visit_predicat}
+                    WHERE ov.origin=o.id {type_predicat}
+                )
+                """
 
         if not count:
             query += "OFFSET %s LIMIT %s"
@@ -1038,6 +1115,7 @@ class Db(BaseDb):
         limit: int = 50,
         regexp: bool = False,
         with_visit: bool = False,
+        visit_types: Optional[List[str]] = None,
         cur=None,
     ):
         """Search for origins whose urls contain a provided string pattern
@@ -1060,6 +1138,7 @@ class Db(BaseDb):
             limit=limit,
             regexp=regexp,
             with_visit=with_visit,
+            visit_types=visit_types,
             cur=cur,
         )
         yield from cur
@@ -1130,6 +1209,7 @@ class Db(BaseDb):
     """The list of context columns for all artifact types."""
 
     _raw_extrinsic_metadata_insert_cols = [
+        "id",
         "type",
         "target",
         "authority_id",
@@ -1146,7 +1226,7 @@ class Db(BaseDb):
         INSERT INTO raw_extrinsic_metadata
             ({', '.join(_raw_extrinsic_metadata_insert_cols)})
         VALUES ({', '.join('%s' for _ in _raw_extrinsic_metadata_insert_cols)})
-        ON CONFLICT (target, authority_id, discovery_date, fetcher_id)
+        ON CONFLICT (id)
         DO NOTHING
     """
 
@@ -1178,6 +1258,7 @@ class Db(BaseDb):
 
     def raw_extrinsic_metadata_add(
         self,
+        id: bytes,
         type: str,
         target: str,
         discovery_date: datetime.datetime,
@@ -1196,6 +1277,7 @@ class Db(BaseDb):
     ):
         query = self._raw_extrinsic_metadata_insert_query
         args: Dict[str, Any] = dict(
+            id=id,
             type=type,
             target=target,
             authority_id=authority_id,
